@@ -35,8 +35,8 @@ class EnviarPedido(Enviar):
         self.envio_por_querystring = True
 
     def gerar_dados_de_envio(self):
-        notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta.id)
-        parametros = ParametrosPayPal("paypal", id=self.pedido.conta.id)
+        notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta_id)
+        parametros = ParametrosPayPal("paypal", id=self.pedido.conta_id)
         express_checkout = ExpressCheckout(
             user=parametros.username,
             pwd=parametros.password,
@@ -68,7 +68,7 @@ class EnviarPedido(Enviar):
         )
         for indice, item in enumerate(self.pedido.itens.all()):
             self.define_valor_de_atributo_de_item(express_checkout, "NAME", indice, item.nome[:127])
-            self.define_valor_de_atributo_de_item(express_checkout, "DESC", indice, item.produto.descricao_completa[:127])
+            self.define_valor_de_atributo_de_item(express_checkout, "DESC", indice, self.descricao_completa_de_item(item))
             self.define_valor_de_atributo_de_item(express_checkout, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(express_checkout, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
             self.define_valor_de_atributo_de_item(express_checkout, "NUMBER", indice, item.sku[:127])
@@ -97,3 +97,8 @@ class EnviarPedido(Enviar):
             return {"content": {"url": url}, "status": 200, "reenviar": False, "identificador": retorno["token"]}
 
         return {"content": retorno, "status": 500, "reenviar": False}
+
+    def descricao_completa_de_item(self, item):
+        if item.produto.descricao_completa:
+            return item.produto.descricao_completa[:127]
+        return ""
