@@ -134,8 +134,8 @@ class Registro(RegistroBase):
         return self._pedido
 
     def gerar_dados_de_envio(self):
-        notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta.id)
-        parametros = ParametrosPayPal("paypal", id=self.pedido.conta.id)
+        notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta_id)
+        parametros = ParametrosPayPal("paypal", id=self.pedido.conta_id)
         ExpressCheckout.cria_payment_request()
         ExpressCheckout.cria_shipto()
         for item in range(0, len(self.pedido.itens.all())):
